Documentation
¶
Index ¶
- type GSM
- func (modem *GSM) Connect() (err error)
- func (modem *GSM) Expect(possibilities []string) (string, error)
- func (modem *GSM) Read(number int) string
- func (modem *GSM) Send(command string)
- func (modem *GSM) WriteCommand(command string, waitCallback bool) string
- func (modem *GSM) WriteMessage(number string, message string) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type GSM ¶
*-------------------------------------------------------------------------- * GSM attributes *-------------------------------------------------------------------------- * * GMS struct defines the config attributes of the external device, * to make a connection between the core-engine/system and external device. * * @var string ComPort | Serial port communication (hardware interface) * @var int BaudRate | Serial port transferring - * (rate information transferred in maximum 'x' bits per second) * @var os Port | External device port * @var string DeviceId | External device id/name
func NewGSMModem ¶
*-------------------------------------------------------------------------- * Set The Config *-------------------------------------------------------------------------- * * Here we will set the environment configuration. * * @return struct GSM
func (*GSM) Connect ¶
*-------------------------------------------------------------------------- * Make a connection *-------------------------------------------------------------------------- * * Here we will be trying to connect with the core device, * the serial port configuration is needed and will be applying * to opens a serial port with the specified configuration. * * @var tarm/serial.Config config * * @do initialized * @return error if !initialized
func (*GSM) Expect ¶
*-------------------------------------------------------------------------- * *-------------------------------------------------------------------------- * * * * @return string
func (*GSM) Read ¶
*-------------------------------------------------------------------------- * *-------------------------------------------------------------------------- * * * * @return string
func (*GSM) Send ¶
*-------------------------------------------------------------------------- * *-------------------------------------------------------------------------- * * * * @return string
func (*GSM) WriteCommand ¶
*-------------------------------------------------------------------------- * *-------------------------------------------------------------------------- * * * * @return string